==> hyades.source_3.0.0_20040621_1225.zip: org/eclipse/hyades/uml2sd/ui/actions/widgets/SearchFilterDialog.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.uml2sd.ui.actions.widgets;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.hyades.uml2sd.ui.SDViewerPlugin;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFilterProvider;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFindProvider;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDGraphNodeSupporter;
import org.eclipse.hyades.uml2sd.ui.core.AsyncMessage;
import org.eclipse.hyades.uml2sd.ui.core.AsyncMessageReturn;
import org.eclipse.hyades.uml2sd.ui.core.GraphNode;
import org.eclipse.hyades.uml2sd.ui.core.Lifeline;
import org.eclipse.hyades.uml2sd.ui.core.Stop;
import org.eclipse.hyades.uml2sd.ui.core.SyncMessage;
import org.eclipse.hyades.uml2sd.ui.core.SyncMessageReturn;
import org.eclipse.hyades.uml2sd.ui.view.SDView;
import org.eclipse.hyades.uml2sd.util.ContextIDs;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.DialogSettings;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.TabFolder;
import org.eclipse.ui.help.WorkbenchHelp;

/**
 * This is the common dialog to define Find and/or Filter Criteria(s)
 */
public class SearchFilterDialog extends Dialog {
	
	private static final String FIND_CRITERIA = "findCriteria"; //$NON-NLS-1$
	private static final String FIND_EXPRESSION_LIST = "findExpressionList"; //$NON-NLS-1$
	private static final int MAX_EXPRESSION_LIST = 7;
	
	/**
	 * viewer
	 */
	private SDView viewer = null;

	/**
	 * tab with the controls for a Criteria
	 */
	private TabFolder tab = null;
	
	/**
	 * content with what
	 */
	private TabContents content = null;

	/**
	 * Criteria updated by this dialog
	 */
	private Criteria criteria = null;	
	
	/**
	 * find/filter provider telling wich graph nodes are supported
	 */
	private ISDGraphNodeSupporter provider = null;
	
	/**
	 * okText is the text for the Ok button and title is the title of the dialog.<br>
	 * Both depend on the usage that is done of this dialog (find or filter).
	 */
	private String okText, title;

	/**
	 * List of string expressions that have been searched already
	 */
	private String[] expressionList;
	
	/**
	 * find is true if the dialog is for the find feature and false for filter feature
	 */
	private boolean find;
	 
	/**
	 * @see org.eclipse.jface.dialogs.Dialog#createDialogArea(org.eclipse.swt.widgets.Composite)
	 */
	public Control createDialogArea(Composite arg0) 
	{
		if (provider instanceof ISDFindProvider)
			WorkbenchHelp.setHelp(arg0,SDViewerPlugin.getId()+ContextIDs.UML2SDFIND);
		else if (provider instanceof ISDFilterProvider)
			WorkbenchHelp.setHelp(arg0,SDViewerPlugin.getId()+ContextIDs.UML2SDFILTER);
		expressionList = SDViewerPlugin.getDefault().getDialogSettings().getArray(FIND_EXPRESSION_LIST);
		if (expressionList == null) {
			expressionList = new String[0];
		}
		return new TabContents(arg0, provider, getButton(IDialogConstants.OK_ID), find ? expressionList : null);
	}
	
	/**
	 * @param theView
	 * @param _provider
	 */
	public SearchFilterDialog (SDView view_, ISDGraphNodeSupporter provider_, boolean filter_, int style) {
		super (view_.getSDWidget().getShell());
		setShellStyle(SWT.DIALOG_TRIM | style);
		provider = provider_;
		viewer = view_;
		find = !filter_;
	}
	
	
	/**
	 * Open the dialog box
	 */
	public int open()
	{
		create();
		
		if (find) {
			loadFindCriteria();
		}
		if (criteria == null) {
			criteria = new Criteria();
			criteria.setLifeLineSelected(provider.isLifelineSupported());
			criteria.setSyncMessageSelected(provider.isSyncMessageSupported());
			criteria.setSyncMessageReturnSelected(provider.isSyncMessageReturnSupported());
			criteria.setAsyncMessageSelected(provider.isAsyncMessageSupported());
			criteria.setAsyncMessageReturnSelected(provider.isAsyncMessageReturnSupported());
			criteria.setStopSelected(provider.isStopSupported());
		}
		copyFromCriteria(criteria);
		
		if (okText != null) {
			getButton(IDialogConstants.OK_ID).setText(okText);
		} else {
			getButton(IDialogConstants.OK_ID).setText(SDViewerPlugin.getResourceString("SEARCH_DIALOG_SEARCH_BUTTON")); //$NON-NLS-1$
		}
		
		if (find) {
			getButton(IDialogConstants.CANCEL_ID).setText(SDViewerPlugin.getResourceString("SEARCH_DIALOG_CLOSE_BUTTON")); //$NON-NLS-1$
		}

		Button okButton = getButton(IDialogConstants.OK_ID);
		((TabContents)getDialogArea()).setOkButton(okButton);
		if (criteria == null ||
			!((criteria.getExpression() != null && !criteria.getExpression().equals("")) && //$NON-NLS-1$
			  (criteria.isAsyncMessageReturnSelected() ||
			   criteria.isAsyncMessageSelected() ||
			   criteria.isLifeLineSelected() ||
			   criteria.isStopSelected() ||
			   criteria.isSyncMessageReturnSelected() ||
			   criteria.isSyncMessageSelected()))) {
			okButton.setEnabled(false);
		}
			
		if (title != null) {
			getShell().setText(title);
		} else {
			getShell().setText(SDViewerPlugin.getResourceString("SEARCH_DIALOG_TITLE")); //$NON-NLS-1$
		}
		
		getShell().pack();
		getShell().setLocation(getShell().getDisplay().getCursorLocation());

		criteria = null;
		return super.open();
	}
	
	/**
	 * 
	 */
	private void loadFindCriteria() {
		DialogSettings section = (DialogSettings)SDViewerPlugin.getDefault().getDialogSettings().getSection(FIND_CRITERIA);
		List selection = viewer.getSDWidget().getSelection();
		if (selection == null || selection.size() != 1) {
			if (section != null) {
				criteria = new Criteria();
				criteria.load(section);
			}
		} else {
			GraphNode gn = (GraphNode)selection.get(0);
			criteria = new Criteria();
			criteria.setExpression(gn.getName());
			criteria.setCaseSenstiveSelected(true);
			if (gn instanceof Lifeline &&
				provider.isLifelineSupported()) {
				criteria.setLifeLineSelected(true);
			} else if (gn instanceof SyncMessageReturn &&
					   provider.isSyncMessageReturnSupported()) {
				criteria.setSyncMessageReturnSelected(true);
			} else if ((gn instanceof SyncMessageReturn ||
					    gn instanceof SyncMessage) &&
					   provider.isSyncMessageSupported()) {
				criteria.setSyncMessageSelected(true);
			} else if (gn instanceof AsyncMessageReturn &&
					   provider.isAsyncMessageReturnSupported()) {
				criteria.setAsyncMessageReturnSelected(true);
			} else if ((gn instanceof AsyncMessageReturn ||
					    gn instanceof AsyncMessage)  &&
					   provider.isAsyncMessageSupported()) {
				criteria.setAsyncMessageSelected(true);
			} else if (gn instanceof Stop &&
					   provider.isStopSupported()) {
				criteria.setStopSelected(true);
			}
		}
	}

	/**
	 * Called when the dialog box ok button is pressed
	 * and call back the appropriate action provider (ISDFilterProvider or ISDFindProvider)
	 */
	public void okPressed()
	{
		copyToCriteria();
		if (!find) {
			super.close(); // Filter is modal
		}
		if ((provider != null) && (provider instanceof ISDFindProvider) && find) {
			boolean result = ((ISDFindProvider)provider).find(criteria);
			TabContents content = getTabContents();
			content.setResult(result);
		}
	}
	
	/**
	 *
	 */
	public void cancelPressed() {
		if (find) {
			copyToCriteria();
			if (provider instanceof ISDFindProvider) {
				((ISDFindProvider)provider).cancel();
			}
			saveCriteria();
		}
		super.cancelPressed();
	}
	
	/**
	 * 
	 */
	public void saveCriteria() {
		DialogSettings settings = (DialogSettings)SDViewerPlugin.getDefault().getDialogSettings();
		DialogSettings section = (DialogSettings)settings.getSection(FIND_CRITERIA);
		if (section == null) {
			section = (DialogSettings)settings.addNewSection(FIND_CRITERIA);
		}
		criteria.save(section);

		if (criteria.getExpression().length() > 0) {
//			System.out.println(criteria.getExpression().intern());
//			System.out.println(expressionList.length);
			ArrayList list = new ArrayList();
			for (int i = 0; i < expressionList.length; i++) {
				list.add(expressionList[i].intern());
			}
			// Remove the used expression if one from the dropdown list
			list.remove(criteria.getExpression().intern());
			// Put the new expression at the beginning
			list.add(0, criteria.getExpression().intern());
//			System.out.println(list.size());
			// Fill in the expressionList, truncating to MAX_EXPRESSION_LIST
			int size = Math.min(list.size(), MAX_EXPRESSION_LIST);
			String []temp = new String[size];
			for (int i = 0; i < size; i++) {
				temp[i] = (String)list.get(i);
			}
			expressionList = temp;
			settings.put(FIND_EXPRESSION_LIST, expressionList);
		}
	}

	/**
	 *
	 */
	public Criteria getCriteria() {
		return criteria;
	}

	/**
	 * @param criteria_
	 */
	public void setCriteria(Criteria criteria_) {
		criteria = criteria_;
	}

	/**
	 * Get the current end-user settings from the dialog to a Criteria
	 * @param content
	 */
	public void copyToCriteria() {
		criteria = new Criteria();
		TabContents content = getTabContents();
		criteria.setLifeLineSelected(content.getLifelineButtonSelection());
		criteria.setSyncMessageSelected(content.getSynMessageButtonSelection());
		criteria.setSyncMessageReturnSelected(content.getSynMessageReturnButtonSelection());
		criteria.setAsyncMessageSelected(content.getAsynMessageButtonSelection());
		criteria.setAsyncMessageReturnSelected(content.getAsynMessageReturnButtonSelection());
		criteria.setStopSelected(content.getStopButtonSelection());
		criteria.setCaseSenstiveSelected(content.getCaseSensitiveSelection());
		criteria.setExpression(content.getSearchText());
	}

	/**
	 * @return
	 * @todo Generated comment
	 */
	private TabContents getTabContents() {
		TabContents content = null;
		if (tab == null)
			content = (TabContents)getDialogArea();
		else content = (TabContents)tab.getSelection()[0].getControl();
		return content;
	}

	/**
	 * Initialize the dialog with the settings of an existing Criteria<br>
	 * Criteria must not be null and the TabContents must have been created
	 * @param from
	 */
	public void copyFromCriteria(Criteria from) {
		TabContents content = getTabContents();
		content.setLifelineButtonSelection(from.isLifeLineSelected());
		content.setSynMessageButtonSelection(from.isSyncMessageSelected());
		content.setSynMessageReturnButtonSelection(from.isSyncMessageReturnSelected());
		content.setAsynMessageButtonSelection(from.isAsyncMessageSelected());
		content.setAsynMessageReturnButtonSelection(from.isSyncMessageReturnSelected());
		content.setStopButtonSelection(from.isStopSelected());
		content.setCaseSensitiveSelection(from.isCaseSenstiveSelected());
		if (from.getExpression() != null) {
			content.setSearchText(from.getExpression());
		}
	}

	/**
	 * @param okText_
	 */
	public void setOkText(String okText_) {
		okText = okText_;
	}

	/**
	 * @param title_
	 */
	public void setTitle(String title_) {
		title = title_;
	}
}

==> hyades.source_3.1.0_20041019_1201.zip: org/eclipse/hyades/uml2sd/ui/actions/widgets/SearchFilterDialog.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.uml2sd.ui.actions.widgets;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.hyades.uml2sd.ui.SDViewerPlugin;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFilterProvider;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFindProvider;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDGraphNodeSupporter;
import org.eclipse.hyades.uml2sd.ui.core.AsyncMessage;
import org.eclipse.hyades.uml2sd.ui.core.AsyncMessageReturn;
import org.eclipse.hyades.uml2sd.ui.core.GraphNode;
import org.eclipse.hyades.uml2sd.ui.core.Lifeline;
import org.eclipse.hyades.uml2sd.ui.core.Stop;
import org.eclipse.hyades.uml2sd.ui.core.SyncMessage;
import org.eclipse.hyades.uml2sd.ui.core.SyncMessageReturn;
import org.eclipse.hyades.uml2sd.ui.view.SDView;
import org.eclipse.hyades.uml2sd.util.ContextIDs;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.DialogSettings;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.TabFolder;
import org.eclipse.ui.help.WorkbenchHelp;

/**
 * This is the common dialog to define Find and/or Filter Criteria(s)
 */
public class SearchFilterDialog extends Dialog {
	
	private static final String FIND_CRITERIA = "findCriteria"; //$NON-NLS-1$
	private static final String FIND_EXPRESSION_LIST = "findExpressionList"; //$NON-NLS-1$
	private static final String FILTER_CRITERIA = "filterCriteria"; //$NON-NLS-1$
	private static final String FILTER_EXPRESSION_LIST = "filterExpressionList"; //$NON-NLS-1$
	private static final int MAX_EXPRESSION_LIST = 7;
	
	/**
	 * viewer
	 */
	private SDView viewer = null;

	/**
	 * tab with the controls for a Criteria
	 */
	private TabFolder tab = null;
	
	/**
	 * content with what
	 */
	private TabContents content = null;

	/**
	 * Criteria updated by this dialog
	 */
	private Criteria criteria = null;	
	
	/**
	 * find/filter provider telling wich graph nodes are supported
	 */
	private ISDGraphNodeSupporter provider = null;
	
	/**
	 * okText is the text for the Ok button and title is the title of the dialog.<br>
	 * Both depend on the usage that is done of this dialog (find or filter).
	 */
	private String okText, title;

	/**
	 * List of string expressions that have been searched already
	 */
	private String[] expressionList;
	
	/**
	 * find is true if the dialog is for the find feature and false for filter feature
	 */
	private boolean find;
	 
	/**
	 * @see org.eclipse.jface.dialogs.Dialog#createDialogArea(org.eclipse.swt.widgets.Composite)
	 */
	public Control createDialogArea(Composite arg0) 
	{
		if (provider instanceof ISDFindProvider)
			WorkbenchHelp.setHelp(arg0,SDViewerPlugin.getId()+ContextIDs.UML2SDFIND);
		else if (provider instanceof ISDFilterProvider)
			WorkbenchHelp.setHelp(arg0,SDViewerPlugin.getId()+ContextIDs.UML2SDFILTER);
		if (find)
			expressionList = SDViewerPlugin.getDefault().getDialogSettings().getArray(FIND_EXPRESSION_LIST);
		else expressionList = SDViewerPlugin.getDefault().getDialogSettings().getArray(FILTER_EXPRESSION_LIST);
		if (expressionList == null) {
			expressionList = new String[0];
		}
		return new TabContents(arg0, provider, getButton(IDialogConstants.OK_ID), expressionList );
	}
	
	/**
	 * @param theView
	 * @param _provider
	 */
	public SearchFilterDialog (SDView view_, ISDGraphNodeSupporter provider_, boolean filter_, int style) {
		super (view_.getSDWidget().getShell());
		setShellStyle(SWT.DIALOG_TRIM | style);
		provider = provider_;
		viewer = view_;
		find = !filter_;
	}
	
	
	/**
	 * Open the dialog box
	 */
	public int open()
	{
		create();
		
		if (criteria == null)
			loadCriteria();
		if (criteria == null) {
			criteria = new Criteria();
			criteria.setLifeLineSelected(provider.isLifelineSupported());
			criteria.setSyncMessageSelected(provider.isSyncMessageSupported());
			criteria.setSyncMessageReturnSelected(provider.isSyncMessageReturnSupported());
			criteria.setAsyncMessageSelected(provider.isAsyncMessageSupported());
			criteria.setAsyncMessageReturnSelected(provider.isAsyncMessageReturnSupported());
			criteria.setStopSelected(provider.isStopSupported());
		}
		copyFromCriteria(criteria);
		
		if (okText != null) {
			getButton(IDialogConstants.OK_ID).setText(okText);
		} else {
			getButton(IDialogConstants.OK_ID).setText(SDViewerPlugin.getResourceString("SEARCH_DIALOG_SEARCH_BUTTON")); //$NON-NLS-1$
		}
		
		if (find) {
			getButton(IDialogConstants.CANCEL_ID).setText(SDViewerPlugin.getResourceString("SEARCH_DIALOG_CLOSE_BUTTON")); //$NON-NLS-1$
		}

		Button okButton = getButton(IDialogConstants.OK_ID);
		((TabContents)getDialogArea()).setOkButton(okButton);
		if (criteria == null ||
			!((criteria.getExpression() != null && !criteria.getExpression().equals("")) && //$NON-NLS-1$
			  (criteria.isAsyncMessageReturnSelected() ||
			   criteria.isAsyncMessageSelected() ||
			   criteria.isLifeLineSelected() ||
			   criteria.isStopSelected() ||
			   criteria.isSyncMessageReturnSelected() ||
			   criteria.isSyncMessageSelected()))) {
			okButton.setEnabled(false);
		}
			
		if (title != null) {
			getShell().setText(title);
		} else {
			getShell().setText(SDViewerPlugin.getResourceString("SEARCH_DIALOG_TITLE")); //$NON-NLS-1$
		}
		
		getShell().pack();
		getShell().setLocation(getShell().getDisplay().getCursorLocation());

		criteria = null;
		return super.open();
	}
	
	/**
	 * 
	 */
	private void loadCriteria() {
		
		String CRITERIA = FIND_CRITERIA;
		if (!find)
			CRITERIA = FILTER_CRITERIA;
	
		DialogSettings section = (DialogSettings)SDViewerPlugin.getDefault().getDialogSettings().getSection(CRITERIA);
		List selection = viewer.getSDWidget().getSelection();
		if ((selection == null || selection.size() != 1)||(!find)) {
			if (section != null) {
				criteria = new Criteria();
				criteria.load(section);
			}
		} else {
			GraphNode gn = (GraphNode)selection.get(0);
			criteria = new Criteria();
			criteria.setExpression(gn.getName());
			criteria.setCaseSenstiveSelected(true);
			if (gn instanceof Lifeline &&
				provider.isLifelineSupported()) {
				criteria.setLifeLineSelected(true);
			} else if (gn instanceof SyncMessageReturn &&
					   provider.isSyncMessageReturnSupported()) {
				criteria.setSyncMessageReturnSelected(true);
			} else if ((gn instanceof SyncMessageReturn ||
					    gn instanceof SyncMessage) &&
					   provider.isSyncMessageSupported()) {
				criteria.setSyncMessageSelected(true);
			} else if (gn instanceof AsyncMessageReturn &&
					   provider.isAsyncMessageReturnSupported()) {
				criteria.setAsyncMessageReturnSelected(true);
			} else if ((gn instanceof AsyncMessageReturn ||
					    gn instanceof AsyncMessage)  &&
					   provider.isAsyncMessageSupported()) {
				criteria.setAsyncMessageSelected(true);
			} else if (gn instanceof Stop &&
					   provider.isStopSupported()) {
				criteria.setStopSelected(true);
			}
		}
	}

	/**
	 * Called when the dialog box ok button is pressed
	 * and call back the appropriate action provider (ISDFilterProvider or ISDFindProvider)
	 */
	public void okPressed()
	{
		copyToCriteria();
		if (!find) {
			saveCriteria();
			super.close(); // Filter is modal
		}
		if ((provider != null) && (provider instanceof ISDFindProvider) && find) {
			boolean result = ((ISDFindProvider)provider).find(criteria);
			TabContents content = getTabContents();
			content.setResult(result);
		}
	}
	
	/**
	 *
	 */
	public void cancelPressed() {
		if (find) {
			copyToCriteria();
			if (provider instanceof ISDFindProvider) {
				((ISDFindProvider)provider).cancel();
			}
			saveCriteria();
		}
		super.cancelPressed();
	}
	
	/**
	 * 
	 */
	public void saveCriteria() {
		String CRITERIA = FIND_CRITERIA;
		String EXPRESSION_LIST = FIND_EXPRESSION_LIST;
		if (!find)
		{
			CRITERIA = FILTER_CRITERIA;
			EXPRESSION_LIST = FILTER_EXPRESSION_LIST;
		}
		DialogSettings settings = (DialogSettings)SDViewerPlugin.getDefault().getDialogSettings();
		DialogSettings section = (DialogSettings)settings.getSection(CRITERIA);
		if (section == null) {
			section = (DialogSettings)settings.addNewSection(CRITERIA);
		}
		criteria.save(section);

		if (criteria.getExpression().length() > 0) {
			ArrayList list = new ArrayList();
			for (int i = 0; i < expressionList.length; i++) {
				list.add(expressionList[i].intern());
			}
			// Remove the used expression if one from the dropdown list
			list.remove(criteria.getExpression().intern());
			// Put the new expression at the beginning
			list.add(0, criteria.getExpression().intern());
			// Fill in the expressionList, truncating to MAX_EXPRESSION_LIST
			int size = Math.min(list.size(), MAX_EXPRESSION_LIST);
			String []temp = new String[size];
			for (int i = 0; i < size; i++) {
				temp[i] = (String)list.get(i);
			}
			expressionList = temp;
			settings.put(EXPRESSION_LIST, expressionList);
		}
	}

	/**
	 *
	 */
	public Criteria getCriteria() {
		return criteria;
	}

	/**
	 * @param criteria_
	 */
	public void setCriteria(Criteria criteria_) {
		criteria = criteria_;
	}

	/**
	 * Get the current end-user settings from the dialog to a Criteria
	 * @param content
	 */
	public void copyToCriteria() {
		criteria = new Criteria();
		TabContents content = getTabContents();
		criteria.setLifeLineSelected(content.getLifelineButtonSelection());
		criteria.setSyncMessageSelected(content.getSynMessageButtonSelection());
		criteria.setSyncMessageReturnSelected(content.getSynMessageReturnButtonSelection());
		criteria.setAsyncMessageSelected(content.getAsynMessageButtonSelection());
		criteria.setAsyncMessageReturnSelected(content.getAsynMessageReturnButtonSelection());
		criteria.setStopSelected(content.getStopButtonSelection());
		criteria.setCaseSenstiveSelected(content.getCaseSensitiveSelection());
		criteria.setExpression(content.getSearchText());
	}

	/**
	 * @return
	 * @todo Generated comment
	 */
	private TabContents getTabContents() {
		TabContents content = null;
		if (tab == null)
			content = (TabContents)getDialogArea();
		else content = (TabContents)tab.getSelection()[0].getControl();
		return content;
	}

	/**
	 * Initialize the dialog with the settings of an existing Criteria<br>
	 * Criteria must not be null and the TabContents must have been created
	 * @param from
	 */
	public void copyFromCriteria(Criteria from) {
		TabContents content = getTabContents();
		content.setLifelineButtonSelection(from.isLifeLineSelected());
		content.setSynMessageButtonSelection(from.isSyncMessageSelected());
		content.setSynMessageReturnButtonSelection(from.isSyncMessageReturnSelected());
		content.setAsynMessageButtonSelection(from.isAsyncMessageSelected());
		content.setAsynMessageReturnButtonSelection(from.isSyncMessageReturnSelected());
		content.setStopButtonSelection(from.isStopSelected());
		content.setCaseSensitiveSelection(from.isCaseSenstiveSelected());
		if (from.getExpression() != null) {
			content.setSearchText(from.getExpression());
		}
	}

	/**
	 * @param okText_
	 */
	public void setOkText(String okText_) {
		okText = okText_;
	}

	/**
	 * @param title_
	 */
	public void setTitle(String title_) {
		title = title_;
	}
}
